@@ -50,23 +50,44 @@
  * and tag lists. There is one global tag list for the whole array, one tag list for each dimension, and one
  * tag list for each element component.\n
  *
- * The data can either be managed completely in memory, or it can be read and written block-wise.
- *
- * Additionally, low-level input/output and data manipulation functions are provided for applications that need to
- * implement their own custom data management.
+ * The array data can be read and written in one of three ways:
+ * - completely in memory (for arrays that are not too big),
+ * - stream-based (for streamable tasks),
+ * - or block-based (for random access to the array data).
  *
  * The library provides interfaces for C and C++. See the <a href="files.html">Files</a> section.
  *
  * \section examples Examples
  *
- * - <a href="example.c.html">Introductory example written in C</a>
- * - <a href="example.cpp.html">Introductory example written in C++</a>
+ * Examples written in C:
+ * - <a href="example-basic.c.html">Introductory example</a>
+ * - <a href="example-tags.c.html">Using tags</a>
+ * - <a href="example-stream-io.c.html">Stream-based input/output</a>
+ * - <a href="example-block-io.c.html">Block-based input/output</a>
  *
- * \page example.c Introductory example written in C
- * \include example.c
+ * Examples written in C++:
+ * - <a href="example-basic.cpp.html">Introductory example</a>
+ * - <a href="example-tags.cpp.html">Using tags</a>
+ * - <a href="example-stream-io.cpp.html">Stream-based input/output</a>
+ * - <a href="example-block-io.cpp.html">Block-based input/output</a>
  *
- * \page example.cpp Introductory example written in C++
- * \include example.cpp
+ * \page example-basic.c Examples written in C: Introductory example
+ * \include example-basic.c
+ * \page example-tags.c Examples written in C: Using tags
+ * \include example-tags.c
+ * \page example-stream-io.c Examples written in C: Stream-based input/output
+ * \include example-stream-io.c
+ * \page example-block-io.c Examples written in C: Block-based input/output
+ * \include example-block-io.c
+ *
+ * \page example-basic.cpp Examples written in C++: Introductory example
+ * \include example-basic.cpp
+ * \page example-tags.cpp Examples written in C++: Using tags
+ * \include example-tags.cpp
+ * \page example-stream-io.cpp Examples written in C++: Stream-based input/output
+ * \include example-stream-io.cpp
+ * \page example-block-io.cpp Examples written in C++: Block-based input/output
+ * \include example-block-io.cpp
  */
 
 
@@ -1020,6 +1041,26 @@ GTA_ATTR_WARN_UNUSED_RESULT GTA_ATTR_NONNULL_ALL GTA_ATTR_NOTHROW;
 
 /*@{*/
 
+/**
+ * \brief               Transform a linear index to array indices.
+ * \param header        The header.
+ * \param index         The linear index.
+ * \param indices       The array indices.
+ */
+extern GTA_EXPORT void
+gta_linear_index_to_indices(const gta_header_t *GTA_RESTRICT header, uintmax_t index, uintmax_t *GTA_RESTRICT indices)
+GTA_ATTR_NONNULL_ALL GTA_ATTR_NOTHROW;
+
+/**
+ * \brief               Transform array indices to a linear index.
+ * \param header        The header.
+ * \param indices       The array indices.
+ * \return              The linear index.
+ */
+extern GTA_EXPORT uintmax_t
+gta_indices_to_linear_index(const gta_header_t *GTA_RESTRICT header, const uintmax_t *GTA_RESTRICT indices)
+GTA_ATTR_NONNULL_ALL GTA_ATTR_PURE GTA_ATTR_NOTHROW;
+
 /**
  * \brief               Get the address of an array element (non-modifiable).
  * \param header        The header.
